#!/bin/bash
# Copyright 2006-2007 Fonality, Inc. ALL RIGHTS RESERVED

DISK_USAGE_LIMIT=50
FON_BACKUP=/root/fon-backup
FON_FILES_TEMPLATE=/tmp/fon-backup.files
FON_FILES=/tmp/fon-backup-real.files

# Check Disk Space before we proceed
GET_DISK_USAGE=`/bin/df -hP /`
DISK_USAGE=`echo $GET_DISK_USAGE | awk '{print $12}'| sed 's/%//'`
if [ $DISK_USAGE -gt $DISK_USAGE_LIMIT ]; then
	SKIP_DIR=/var/spool/asterisk	
	TAG="-NO_SPOOL"
	echo "NOTE: Less than $((100 - $DISK_USAGE))% of disk available (LIMIT=$((100 - $DISK_USAGE_LIMIT))%), skipping $SKIP_DIR"
else
	SKIP_DIR="no_skips"
	echo "NOTE: $((100 - $DISK_USAGE))% of disk available (LIMIT=$((100 - $DISK_USAGE_LIMIT))%), performing full backup"
fi

# Match FON-Core VERSION
FON_VERSION=`/usr/sbin/asterisk -V | awk '{print $3}'`

if [ -z $FON_VERSION ]; then
	# Match Asterisk VERSION
	FON_VERSION=`/usr/sbin/asterisk -V | awk '{print $2}'`
fi

SERVER_NAME=`uname -n`
YUM_SERVER=`perl -e "print ${SERVER_NAME} =~ /\d{6}/ ? 'yum.trixbox.com' : 'yum.fonality.com'"`

# Get a new template file from yum server
pushd /tmp 1>/dev/null
/usr/bin/wget -q -nd -r -N http://${YUM_SERVER}/backup/`basename $FON_FILES_TEMPLATE`
popd 1> /dev/null

if [ -e $FON_FILES_TEMPLATE ]; then
	if [ -e $FON_FILES ]; then
		rm -f $FON_FILES
	fi

	# Expand filelist to include actual filename listed in directores in template
	for i in `cat $FON_FILES_TEMPLATE`; do
		ls -dU $i 2>/dev/null | grep -v $SKIP_DIR >> $FON_FILES;
	done

	rm -f $FON_FILES_TEMPLATE
else
	echo "ABORT: Template File not found"
	exit 1
fi

if [ -e $FON_FILES ]; then
	echo "Perform full backup of PBX Software"
	mkdir -p $FON_BACKUP
	pushd $FON_BACKUP 1>/dev/null
	TARBALL=fon-backup-$FON_VERSION$TAG-`date +%F-%H%M`.tar
	/bin/tar cpPvf $TARBALL -T $FON_FILES --ignore-failed-read --exclude "/var/log/asterisk" --exclude ".svn"
	/bin/gzip $TARBALL
	popd 1>/dev/null

	if [ -e $FON_FILES ]; then
		rm -f $FON_FILES
	fi

	/usr/bin/logger -t "FONCore" -s "Completed FONCore Backup to $FON_BACKUP/$TARBALL.gz at `date`"
else
	echo "ABORT: Backup File list not found"
	exit 1
fi
