#!/usr/bin/perl

##
# Make a server LBS
#
# Args: primary_server, backup_server
##

use strict;

my $primary = $ARGV[0];
my $backup = $ARGV[1];
my $is_primary = $ARGV[2];
my $type = $ARGV[3];
my $pub_key = $ARGV[4];

if (!$primary || !$backup || !defined($is_primary) || !$type || !$pub_key) {
	print "Invalid input.";
	exit();
}

my $rserver = "s${primary}.$type.fonality.com";
my $bserver = "s${primary}b.$type.fonality.com";
my $standby = "/etc/asterisk/primary";
if ($is_primary) {
	$rserver = "s${backup}.$type.fonality.com";
	$bserver = "s${backup}b.$type.fonality.com";
	$standby = "/etc/asterisk/standby";
}

# add the public SSH key to connect to the other server
system("echo $pub_key >> /root/.ssh/authorized_keys");
system("ssh-keyscan -t rsa $rserver >> /root/.ssh/known_hosts");

# reset any LBS status
system('rm /etc/standby /etc/primary /etc/asterisk/standby /etc/asterisk/primary');

# set the LBS status
system("echo $bserver > $standby");
system("chown nobody:nobody $standby");

# Add sync_redundant to cron, but only if it does not already exist
system('crontab -l > /tmp/crontab.addsync');
system('if grep sync_redundant_server /tmp/crontab.addsync; then true; else echo "*/30 * * * * /usr/bin/perl /var/adm/bin/sync_redundant_server.pl > /dev/null 2>&1" >> /tmp/crontab.addsync; fi');
system('crontab /tmp/crontab.addsync');
system('rm -f /tmp/crontab.addsync');

# run sync_redundant_server immediately. This will stop VoIP registration and make /var/lib/asterisk/sounds/callscreens and other good things.
system('/usr/bin/perl /var/adm/bin/sync_redundant_server.pl');

# if this is the primary server, run sync_redundant on the backup
if ($is_primary) {
	my $ssh = 'ssh -oStrictHostKeyChecking=no -oPasswordAuthentication=no';
	system("$ssh $bserver '/usr/bin/perl /var/adm/bin/sync_redundant_server.pl'");
}

